@@ -217,6 +217,12 @@ seafile_get_path_sync_status (const char *repo_id,
                               int is_dir,
                               GError **error);
 
+int
+seafile_mark_file_locked (const char *repo_id, const char *path, GError **error);
+
+int
+seafile_mark_file_unlocked (const char *repo_id, const char *path, GError **error);
+
 /**
  * seafile_list_dir:
  * List a directory.
@@ -427,7 +433,7 @@ GList *
 seafile_get_orphan_repo_list(GError **error);
 
 GList *
-seafile_list_owned_repos (const char *email, GError **error);
+seafile_list_owned_repos (const char *email, int ret_corrupted, GError **error);
 
 /**
  * seafile_add_chunk_server:
@@ -782,7 +788,8 @@ seafile_revert_dir (const char *repo_id,
  */
 GList *
 seafile_get_deleted (const char *repo_id, int show_days,
-                     const char *path, GError **error);
+                     const char *path, const char *scan_stat,
+                     int limit, GError **error);
 
 /**
  * Generate a new token for (repo_id, email) and return it
@@ -944,4 +951,9 @@ seafile_get_shared_groups_for_subdir (const char *repo_id,
                                       const char *path,
                                       const char *from_user,
                                       GError **error);
+GObject *
+seafile_generate_magic_and_random_key(int enc_version,
+                                      const char* repo_id,
+                                      const char *passwd,
+                                      GError **error);
 #endif
