@@ -14,8 +14,6 @@ WebAccess:
 
 class SeafileAPI(object):
 
-    PATH_NOT_EXIST_PREFIX = 'Path does not exists'
-
     def __init__(self):
         pass
 
@@ -78,8 +76,9 @@ class SeafileAPI(object):
     def get_repo_owner(self, repo_id):
         return seafserv_threaded_rpc.get_repo_owner(repo_id)
 
-    def get_owned_repo_list(self, username):
-        return seafserv_threaded_rpc.list_owned_repos(username)
+    def get_owned_repo_list(self, username, ret_corrupted=False):
+        return seafserv_threaded_rpc.list_owned_repos(username,
+                                                      1 if ret_corrupted else 0)
 
     def get_orphan_repo_list(self):
         return seafserv_threaded_rpc.get_orphan_repo_list()
@@ -158,17 +157,11 @@ class SeafileAPI(object):
 
     def get_file_id_by_commit_and_path(self, repo_id, commit_id, path):
         return seafserv_threaded_rpc.get_file_id_by_commit_and_path(repo_id,
-                                                                    commit_id, path)
+                                                                    commit_id,
+                                                                    path)
 
     def get_dirent_by_path(self, repo_id, path):
-        try:
-            ret = seafserv_threaded_rpc.get_dirent_by_path(repo_id, path)
-        except SearpcError as e:
-            if str(e).startswith(SeafileAPI.PATH_NOT_EXIST_PREFIX):
-                ret = None
-            else:
-                raise e
-        return ret
+        return seafserv_threaded_rpc.get_dirent_by_path(repo_id, path)
 
     def get_file_revisions(self, repo_id, path, max_revision, limit, show_days=-1):
         return seafserv_threaded_rpc.list_file_revisions(repo_id, path,
@@ -204,26 +197,13 @@ class SeafileAPI(object):
 
     def list_dir_by_commit_and_path(self, repo_id,
                                     commit_id, path, offset=-1, limit=-1):
-        try:
-            dir_id = seafserv_threaded_rpc.get_dirid_by_path(repo_id, commit_id, path)
-        except SearpcError as e:
-            if str(e).startswith(SeafileAPI.PATH_NOT_EXIST_PREFIX):
-                dir_id = None
-            else:
-                raise e
+        dir_id = seafserv_threaded_rpc.get_dirid_by_path(repo_id, commit_id, path)
         if dir_id is None:
             return None
         return seafserv_threaded_rpc.list_dir(repo_id, dir_id, offset, limit)
     
     def get_dir_id_by_commit_and_path(self, repo_id, commit_id, path):
-        try:
-            ret = seafserv_threaded_rpc.get_dirid_by_path(repo_id, commit_id, path)
-        except SearpcError as e:
-            if str(e).startswith(SeafileAPI.PATH_NOT_EXIST_PREFIX):
-                ret = None
-            else:
-                raise e
-        return ret
+        return seafserv_threaded_rpc.get_dirid_by_path(repo_id, commit_id, path)
 
     def revert_file(self, repo_id, commit_id, path, username):
         return seafserv_threaded_rpc.revert_file(repo_id, commit_id, path, username)
@@ -231,8 +211,12 @@ class SeafileAPI(object):
     def revert_dir(self, repo_id, commit_id, path, username):
         return seafserv_threaded_rpc.revert_dir(repo_id, commit_id, path, username)
 
-    def get_deleted(self, repo_id, show_days, path='/'):
-        return seafserv_threaded_rpc.get_deleted(repo_id, show_days, path)
+    def get_deleted(self, repo_id, show_days, path='/', scan_stat=None, limit=100):
+        return seafserv_threaded_rpc.get_deleted(repo_id, show_days, path, scan_stat, limit)
+
+    # file lock
+    def check_file_lock(self, repo_id, path, user):
+        return 0
 
     # share repo to user
     def share_repo(self, repo_id, from_username, to_username, permission):
@@ -310,6 +294,9 @@ class SeafileAPI(object):
     def get_group_repos_by_owner(self, username):
         return seafserv_threaded_rpc.get_group_repos_by_owner(username)
 
+    def remove_group_repos_by_owner(self, group_id, username):
+        return seafserv_threaded_rpc.remove_repo_group(group_id, username)
+
     def set_group_repo_permission(self, group_id, repo_id, permission):
         return seafserv_threaded_rpc.set_group_repo_permission(group_id, repo_id,
                                                                permission)
@@ -446,4 +433,7 @@ class SeafileAPI(object):
     def empty_repo_trash_by_owner(self, owner):
         return seafserv_threaded_rpc.empty_repo_trash_by_owner(owner)
 
+    def generate_magic_and_random_key(self, enc_version, repo_id, password):
+        return seafserv_threaded_rpc.generate_magic_and_random_key(enc_version, repo_id, password)
+
 seafile_api = SeafileAPI()
